package
Version:
v1.2.0
Opens a new window with list of versions in this module.
Published: Jan 19, 2025
License: MIT
Opens a new window with license information.
Imports: 2
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type IAudioV1 interface {
Speech(ctx context.Context, req *v1.SpeechReq) (res *v1.SpeechRes, err error)
Transcriptions(ctx context.Context, req *v1.TranscriptionsReq) (res *v1.TranscriptionsRes, err error)
}
Source Files
¶
Directories
¶
Click to show internal directories.
Click to hide internal directories.