package
Version:
v0.2.0
Opens a new window with list of versions in this module.
Published: May 18, 2024
License: MIT
Opens a new window with license information.
Imports: 2
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type IImageV1 interface {
Generations(ctx context.Context, req *v1.GenerationsReq) (res *v1.GenerationsRes, err error)
}
Source Files
¶
Directories
¶
Click to show internal directories.
Click to hide internal directories.